<?php
# generate xhtml output
# Argument: content
# Result: xhtml with content in the body
function getHtml($content) {
	$output = <<<EOT
<?xml version="1.1" encoding="iso-8859-1"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="nl">
<head>
<title>IMAU Cloud Parcel Model</title>
<link rel="stylesheet" href="http://www.phys.uu.nl/~wwwimau/style/imau.css" type="text/css" media="screen"/>
<script type="text/javascript" src="scripts.js"/>
</head>
<body class="main">
$content
<hr/>
<div class="timestamp"> 
Updated: March 11, 2005
</div>
</body>
</html>
EOT;
	return $output;
}

# generate xhtml for the form
# Result: xhtml for the form
function form() {
	extract($_SESSION);
	if (!isset($myRegime)) {
		$myRegime = 2;
	}
	if (!isset($myConcentration)) {
		$myConcentration = 1.00;
	}
	if (!isset($mySolubility)) {
		$mySolubility = 50;
	}
	if (!isset($myVelocity)) {
		$myVelocity = 50;
	}
	if (!isset($myPrecipitation)) {
		$myPrecipitation = 0;
	}
	if (!isset($myChemistry)) {
		$myChemistry = 0;
	}
	if (!isset($myLapse)) {
		$myLapse = 6.00;
	}	
	$form = <<<EOT
<form id="input" action="output.php" method="post" onsubmit="return checkValidity();">
<table>
<tr>
<td>
Aerosol regime
</td>
<td>
<select name="regime">
EOT;
	if ($myRegime == 1) {
		$option1 = "<option selected=\"selected\" value=\"1\">Marine (90% soluble)</option>";
	} else {
		$option1 = "<option value=\"1\">Marine (90% soluble)</option>";
	}
	if ($myRegime == 2) {
		$option2 = "<option selected=\"selected\" value=\"2\">Clean continental (50% soluble)</option>";
	} else {
		$option2 = "<option value=\"2\">Clean continental (50% soluble)</option>";
	}
	if ($myRegime == 3) {
		$option3 = "<option selected=\"selected\" value=\"3\">Polluted (50% soluble)</option>";
	} else {
		$option3 = "<option value=\"3\">Polluted (50% soluble)</option>";
	}
	$form .= $option1.$option2.$option3;
	$form .= <<<EOT
</select>
</td>
</tr>
<tr>
<td>
Scale aerosol concentrations (0.1-10)
</td>
<td>
EOT;
	$form .= "<input name=\"concentration\" value=\"".$myConcentration."\" onkeyup=\"checkValidity();\"/>";
	$form .= <<<EOT
</td>
</tr>
<tr>
<td>
Aerosol solubility (1-100 %)
</td>
<td>
EOT;
	$form .= "<input name=\"solubility\" value=\"".$mySolubility."\" onkeyup=\"checkValidity();\"/>";
	$form .= <<<EOT
</td>
</tr>
<tr>
<td>
Updraft velocity (5-200 cm/s)
</td>
<td>
EOT;
	$form .= "<input name=\"velocity\" value=\"".$myVelocity."\" onkeyup=\"checkValidity();\"/>";
	$form .= <<<EOT
</td>
</tr>
<tr>
<td>
Precipitation
</td>
<td>
EOT;
	$form .= "<input name=\"precipitation\" type=\"checkbox\" value=\"1\"";
	if ($myPrecipitation == 1) {
		$form .= " checked=\"checked\"";
	}
	$form .= "/>";
	$form .= <<<EOT
</td>
</tr>
<tr>
<td>
Chemistry
</td>
<td>
EOT;
	$form .= "<input name=\"chemistry\" type=\"checkbox\" value=\"1\"";
	if ($myChemistry == 1) {
		$form .= " checked=\"checked\"";
	}
	$form .= "/>";
	$form .= <<<EOT
</td>
</tr>
<tr>
<td>
Environmental lapse rate (5-8 &deg;C/km)
</td>
<td>
EOT;
	$form .= "<input name=\"lapse\" value=\"".$myLapse."\" onkeyup=\"checkValidity();\"/>";
	$form .= <<<EOT
</td>
</tr>
<tr>
<td>
<input id="submit" type="submit" value="Run"/> <input type="reset" onclick="document.getElementById('submit').disabled = 0;"/>
</td>
</tr>
</table>
</form>
EOT;
	return $form;
}

session_start();

$body = <<<EOT
<h1>IMAU Cloud Parcel Model</h1>
<h2>The model</h2>
EOT;
$body .= form();
$body .= <<<EOT
<hr/>
<h2>Introduction</h2>
<p>
The IMAU Cloud Parcel Model (ICPM) is a numerical simulation model of cloud drop nucleation and growth. It simulates an air parcel containing aerosol and water vapor. It is initialized with a user-specified aerosol size distribution and chemical composition, with a relative humidity of 99%. The model simulates the ascent of the air parcel, the associated adiabatic cooling and the increase of the supersaturation. For each aerosol size class, the model continuously adapts the wet radius to the changes of the supersaturation. After a while, enough droplets are activated and the supersaturation decreases again. The model exits with general information on the cloud characteristics just above the cloud base. The model can be used to investigate the impact of aerosol concentration, aerosol solubility and updraft speed on the supersaturation and the cloud drop concentration.
</p>
<h2>Input and output</h2>
<p>
The variable parameters are:
</p>
<ul>
<li>Environment: marine, clean continental, polluted (also involves a change of the default solubility)</li>
<li>Scaling: scale aerosol particle concentrations</li>
<li>Solubility: soluble volume fraction, between 0.05 and 1</li>
<li>Meteorology: parcel updraft velocity</li>
</ul>
<p>
You can change these parameters in the form below.
</p>
<p>
After the simulation is ready the output is returned. The text gives a summary of the model results, i.e.,
</p>
<ul>
<li>maximum supersaturation at the cloud base</li>
<li>time at which that occurs</li>
<li>concentration of activated cloud drops</li>
<li>cut-off radius, i.e., the radius of the smallest particles activated at the maximum supersaturation</li>
<li>the average drop radius valid for a LWC of 1 g/m<sup>3</sup></li>
<li>nucleation scavenging efficiencies for particle and mass concentrations</li>
</ul>
<h2>
Feedback
</h2>
<p>
If you have any questions about the ICPM, you can send an e-mail to <a href="mailto:roelofs@phys.uu.nl">Geert-Jan Roelofs</a>. For questions and feedback regarding this website, you can contact <a href="mailto:M.H.Broeken@phys.uu.nl">Marcel Broeken</a>.
</p>
EOT;

print(getHtml($body));
?>